@@ -5,22 +5,17 @@
 #include "AuthDialog.h"
 #include "usersmanager.h"
 
-#include <QProcess>
 #include <QPainter>
-#include <QStandardItemModel>
 #include <QDesktopServices>
-#include <QDialogButtonBox>
 #include <QVBoxLayout>
 #include <QUrl>
 #include <QAbstractButton>
 #include <QButtonGroup>
 
-#include <DHiDPIHelper>
-
-#include <PolkitQt1/Authority>
-#include <PolkitQt1/Details>
+#include <DIcon>
 
 #include <libintl.h>
+#include <dde-shell/dlayershellwindow.h>
 
 DWIDGET_USE_NAMESPACE
 
@@ -301,8 +296,16 @@ bool AuthDialog::event(QEvent *event)
 
 void AuthDialog::initUI()
 {
-    setWindowFlags(windowFlags() | Qt::WindowStaysOnTopHint | Qt::Tool);
-    setWindowFlag(Qt::BypassWindowManagerHint, true);
+    // create window
+    winId();
+    auto wnd = windowHandle();
+    if (wnd) {
+        auto layerShellWnd = ds::DLayerShellWindow::get(wnd);
+        layerShellWnd->setLayer(ds::DLayerShellWindow::LayerOverlay);
+        layerShellWnd->setKeyboardInteractivity(ds::DLayerShellWindow::KeyboardInteractivityOnDemand);
+    } else {
+        qDebug() << "WindowHandle is null!!!";
+    }
     setMinimumWidth(380);
     setOnButtonClickedClose(false);
 
@@ -312,7 +315,7 @@ void AuthDialog::initUI()
     if (!m_iconName.isEmpty() && QIcon::hasThemeIcon(m_iconName)) {
         icon = QIcon::fromTheme(m_iconName).pixmap(static_cast<int>(48 * dpr), static_cast<int>(48 * dpr));
     } else {
-        icon = DHiDPIHelper::loadNxPixmap(":/images/default.svg");
+        icon = Dtk::Gui::DIcon::loadNxPixmap(":/images/default.svg");
     }
     icon.setDevicePixelRatio(dpr);
     setIcon(icon);
